"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const ApiServer_1 = require("./api/ApiServer");
const inversify_1 = require("inversify");
const AppConfig_1 = require("./model/AppConfig");
class ApiApp {
    constructor(appConfig, appContainer) {
        if (appContainer) {
            this.appContainer = appContainer;
        }
        else {
            this.appContainer = new inversify_1.Container({ autoBindInjectable: true });
            if (appConfig) {
                this.appContainer
                    .bind(AppConfig_1.AppConfig)
                    .toConstantValue(new AppConfig_1.AppConfig());
            }
        }
        this.apiServer = this.appContainer.get(ApiServer_1.ApiServer);
    }
    /**
     * Configure the IOC container instance.
     */
    configureApp(configureBlock) {
        configureBlock.apply(this.appContainer);
    }
    /**
     * Configure the lambda-api API instance.
     */
    configureApi(configureBlock) {
        this.apiServer.configure(configureBlock);
    }
    async initialiseControllers(controllersPath) {
        await this.apiServer.discoverAndBuildRoutes(controllersPath, this.appContainer);
    }
}
exports.ApiApp = ApiApp;
//# sourceMappingURL=ApiApp.js.map